@@ -376,10 +376,6 @@ pub struct StudentView {
     #[serde(skip_serializing_if="Option::is_none")]
     pub undergraduate_school: Option<String>,
 
-    #[serde(rename = "specialism")]
-    #[serde(skip_serializing_if="Option::is_none")]
-    pub specialism: Option<String>,
-
 }
 
 impl StudentView {
@@ -398,7 +394,6 @@ impl StudentView {
             email: None,
             phone: None,
             undergraduate_school: None,
-            specialism: None,
         }
     }
 }
@@ -479,12 +474,6 @@ impl std::string::ToString for StudentView {
             params.push(undergraduate_school.to_string());
         }
 
-
-        if let Some(ref specialism) = self.specialism {
-            params.push("specialism".to_string());
-            params.push(specialism.to_string());
-        }
-
         params.join(",").to_string()
     }
 }
@@ -512,7 +501,6 @@ impl std::str::FromStr for StudentView {
             pub email: Vec<String>,
             pub phone: Vec<String>,
             pub undergraduate_school: Vec<String>,
-            pub specialism: Vec<String>,
         }
 
         let mut intermediate_rep = IntermediateRep::default();
@@ -542,7 +530,6 @@ impl std::str::FromStr for StudentView {
                     "email" => intermediate_rep.email.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "phone" => intermediate_rep.phone.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "undergraduateSchool" => intermediate_rep.undergraduate_school.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "specialism" => intermediate_rep.specialism.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing StudentView".to_string())
                 }
             }
@@ -566,7 +553,6 @@ impl std::str::FromStr for StudentView {
             email: intermediate_rep.email.into_iter().next(),
             phone: intermediate_rep.phone.into_iter().next(),
             undergraduate_school: intermediate_rep.undergraduate_school.into_iter().next(),
-            specialism: intermediate_rep.specialism.into_iter().next(),
         })
     }
 }
