@@ -178,31 +178,31 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                 match result {
                             Ok(body) => {
                                 let mut unused_elements = Vec::new();
-                                let param_student: Option<models::Student> = if !body.is_empty() {
+                                let param_student_upsert: Option<models::StudentUpsert> = if !body.is_empty() {
                                     let deserializer = &mut serde_json::Deserializer::from_slice(&*body);
                                     match serde_ignored::deserialize(deserializer, |path| {
                                             warn!("Ignoring unknown field in body: {}", path);
                                             unused_elements.push(path.to_string());
                                     }) {
-                                        Ok(param_student) => param_student,
+                                        Ok(param_student_upsert) => param_student_upsert,
                                         Err(e) => return Ok(Response::builder()
                                                         .status(StatusCode::BAD_REQUEST)
-                                                        .body(Body::from(format!("Couldn't parse body parameter Student - doesn't match schema: {}", e)))
-                                                        .expect("Unable to create Bad Request response for invalid body parameter Student due to schema")),
+                                                        .body(Body::from(format!("Couldn't parse body parameter StudentUpsert - doesn't match schema: {}", e)))
+                                                        .expect("Unable to create Bad Request response for invalid body parameter StudentUpsert due to schema")),
                                     }
                                 } else {
                                     None
                                 };
-                                let param_student = match param_student {
-                                    Some(param_student) => param_student,
+                                let param_student_upsert = match param_student_upsert {
+                                    Some(param_student_upsert) => param_student_upsert,
                                     None => return Ok(Response::builder()
                                                         .status(StatusCode::BAD_REQUEST)
-                                                        .body(Body::from("Missing required body parameter Student"))
-                                                        .expect("Unable to create Bad Request response for missing body parameter Student")),
+                                                        .body(Body::from("Missing required body parameter StudentUpsert"))
+                                                        .expect("Unable to create Bad Request response for missing body parameter StudentUpsert")),
                                 };
 
                                 let result = api_impl.add_student(
-                                            param_student,
+                                            param_student_upsert,
                                         &context
                                     ).await;
                                 let mut response = Response::new(Body::empty());
@@ -248,8 +248,8 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                             },
                             Err(e) => Ok(Response::builder()
                                                 .status(StatusCode::BAD_REQUEST)
-                                                .body(Body::from(format!("Couldn't read body parameter Student: {}", e)))
-                                                .expect("Unable to create Bad Request response due to unable to read body parameter Student")),
+                                                .body(Body::from(format!("Couldn't read body parameter StudentUpsert: {}", e)))
+                                                .expect("Unable to create Bad Request response due to unable to read body parameter StudentUpsert")),
                         }
             },
 
@@ -366,32 +366,32 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                 match result {
                             Ok(body) => {
                                 let mut unused_elements = Vec::new();
-                                let param_student: Option<models::Student> = if !body.is_empty() {
+                                let param_student_upsert: Option<models::StudentUpsert> = if !body.is_empty() {
                                     let deserializer = &mut serde_json::Deserializer::from_slice(&*body);
                                     match serde_ignored::deserialize(deserializer, |path| {
                                             warn!("Ignoring unknown field in body: {}", path);
                                             unused_elements.push(path.to_string());
                                     }) {
-                                        Ok(param_student) => param_student,
+                                        Ok(param_student_upsert) => param_student_upsert,
                                         Err(e) => return Ok(Response::builder()
                                                         .status(StatusCode::BAD_REQUEST)
-                                                        .body(Body::from(format!("Couldn't parse body parameter Student - doesn't match schema: {}", e)))
-                                                        .expect("Unable to create Bad Request response for invalid body parameter Student due to schema")),
+                                                        .body(Body::from(format!("Couldn't parse body parameter StudentUpsert - doesn't match schema: {}", e)))
+                                                        .expect("Unable to create Bad Request response for invalid body parameter StudentUpsert due to schema")),
                                     }
                                 } else {
                                     None
                                 };
-                                let param_student = match param_student {
-                                    Some(param_student) => param_student,
+                                let param_student_upsert = match param_student_upsert {
+                                    Some(param_student_upsert) => param_student_upsert,
                                     None => return Ok(Response::builder()
                                                         .status(StatusCode::BAD_REQUEST)
-                                                        .body(Body::from("Missing required body parameter Student"))
-                                                        .expect("Unable to create Bad Request response for missing body parameter Student")),
+                                                        .body(Body::from("Missing required body parameter StudentUpsert"))
+                                                        .expect("Unable to create Bad Request response for missing body parameter StudentUpsert")),
                                 };
 
                                 let result = api_impl.update_student(
                                             param_id,
-                                            param_student,
+                                            param_student_upsert,
                                         &context
                                     ).await;
                                 let mut response = Response::new(Body::empty());
@@ -445,8 +445,8 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                             },
                             Err(e) => Ok(Response::builder()
                                                 .status(StatusCode::BAD_REQUEST)
-                                                .body(Body::from(format!("Couldn't read body parameter Student: {}", e)))
-                                                .expect("Unable to create Bad Request response due to unable to read body parameter Student")),
+                                                .body(Body::from(format!("Couldn't read body parameter StudentUpsert: {}", e)))
+                                                .expect("Unable to create Bad Request response due to unable to read body parameter StudentUpsert")),
                         }
             },
 
